@@ -2,10 +2,12 @@
 from __future__ import print_function
 
 import argparse
+import contextlib
 import hashlib
 import os
 import subprocess
 import sys
+import tempfile
 
 from binstar_client.utils import get_binstar
 import binstar_client.errors
@@ -16,6 +18,16 @@ from conda_build.build import bldpkg_path
 from conda_build.config import Config
 
 
+@contextlib.contextmanager
+def get_temp_token(token):
+    dn = tempfile.mkdtemp()
+    fn = os.path.join(dn, "binstar.token")
+    with open(fn, "w") as fh:
+        fh.write(token)
+    yield fn
+    shutil.rmtree(dn)
+
+
 def built_distribution_already_exists(cli, meta, owner):
     """
     Checks to see whether the built recipe (aka distribution) already
@@ -54,16 +66,12 @@ def built_distribution_already_exists(cli, meta, owner):
 
 
 def upload(cli, meta, owner, channels):
-    try:
-        with open('binstar.token', 'w') as fh:
-            fh.write(cli.token)
-        subprocess.check_call(['anaconda', '--quiet', '-t', 'binstar.token',
+    with get_temp_token(cli.token) as fn:
+        subprocess.check_call(['anaconda', '--quiet', '-t', fn,
                                'upload', bldpkg_path(meta),
                                '--user={}'.format(owner),
                                '--channel={}'.format(channels)],
                               env=os.environ)
-    finally:
-        os.remove('binstar.token')
 
 
 def distribution_exists_on_channel(binstar_cli, meta, owner, channel='main'):
